==========
References
==========

Algorithms Used
----------------

+ Segal-Halevi, Erel, Avinatan Hassidim, and Yonatan Aumann. "MUDA: a truthful multi-unit double-auction mechanism." Thirty-Second AAAI Conference on Artificial Intelligence. 2018.
+ Huang, Pu, Alan Scheller–Wolf, and Katia Sycara. "Design of a multi–unit double auction e–market." Computational Intelligence 18.4 (2002): 596-617.
+ Blouin, Max R., and Roberto Serrano. "A decentralized market with common values uncertainty: Non-steady states." The Review of Economic Studies 68.2 (2001): 323-346.
